=======
Credits
=======

Development Lead
----------------

* `Ben Lopatin <https://github.com/bennylope>`_

Contributors
------------

* `Arsen Mamikonyan <https://github.com/mamikonyana>`_
* `Patrick Michael Kane <https://github.com/pmkane>`_
